.. _registry_module:

:mod:`pyramid.registry`
---------------------------

.. module:: pyramid.registry

.. autoclass:: Registry

   .. attribute:: settings

     The :term:`deployment settings` object.  See :ref:`deployment_settings`
     for information.

